@@ -12,7 +12,7 @@ import numpy as np
 import random
 from fractions import Fraction
 
-np.seterr(divide="ignore", multiply="ignore")
+np.seterr(divide="ignore")
 _rng = random.Random()
 
 
